@@ -4,6 +4,6 @@ APP_NAME=bindwood
 CHROME_PROVIDERS="content locale"
 CLEAN_UP=1
 ROOT_FILES="couchdb_env.sh"
-ROOT_DIRS="defaults"
+ROOT_DIRS="defaults modules"
 BEFORE_BUILD=
 AFTER_BUILD=
